# Google Drive changelog

## [0.1.1] - 2026-01-09
- Updated connector definition (YAML version 0.1.1)
- Source commit: da9b741b
- SDK version: 0.1.0

## [0.1.0] - 2026-01-08
- Updated connector definition (YAML version 0.1.1)
- Source commit: a87e3446
- SDK version: 0.1.0
